@@ -1,5 +1,3 @@
-# -*- coding: UTF-8 -*-
-
 """
 jaraco.itertools
 Tools for working with iterables.  Complements itertools and more_itertools.
@@ -69,7 +67,7 @@ def bisect(seq, func=bool):
     return queues.get_first_n_queues(2)
 
 
-class GroupbySaved(object):
+class GroupbySaved:
     """
     Split a sequence into n sequences where n is determined by the
     number of distinct values returned by a key function applied to each
@@ -172,8 +170,6 @@ class FetchingQueue(queue.Queue):
             self._fetcher()
         return self.get()
 
-    next = __next__
-
     def __iter__(self):
         while True:
             try:
@@ -185,7 +181,7 @@ class FetchingQueue(queue.Queue):
         self.put_nowait(item)
 
 
-class Count(object):
+class Count:
     """
     A stop object that will count how many times it's been called and return
     False on the N+1st call.  Useful for use with takewhile.
@@ -237,7 +233,7 @@ class Count(object):
         return vars(self) == vars(other)
 
 
-class islice(object):
+class islice:
     """May be applied to an iterable to limit the number of items returned.
     Works similarly to count, except is called only once on an iterable.
     Functionality is identical to islice, except for __str__ and reusability.
@@ -283,7 +279,7 @@ class islice(object):
         return result
 
 
-class LessThanNBlanks(object):
+class LessThanNBlanks:
     """
     An object that when called will return True until n false elements
     are encountered.
@@ -312,7 +308,7 @@ class LessThanNBlanks(object):
         return self.count < self.limit
 
 
-class LessThanNConsecutiveBlanks(object):
+class LessThanNConsecutiveBlanks:
     """
     An object that when called will return True until n consecutive
     false elements are encountered.
@@ -342,7 +338,7 @@ class LessThanNConsecutiveBlanks(object):
         return self.count < self.limit
 
 
-class splitter(object):
+class splitter:
     """
     object that will split a string with the given arguments for each call.
 
@@ -399,12 +395,14 @@ def infiniteCall(f, *args):
     return infinite_call(functools.partial(f, *args))
 
 
-class Counter(object):
+class Counter:
     """
     Wrap an iterable in an object that stores the count of items
     that pass through it.
 
     >>> items = Counter(range(20))
+    >>> items.count
+    0
     >>> values = list(items)
     >>> items.count
     20
@@ -412,70 +410,15 @@ class Counter(object):
 
     def __init__(self, i):
         self.count = 0
-        self._orig_iter = iter(i)
+        self.iter = zip(itertools.count(1), i)
 
     def __iter__(self):
         return self
 
     def __next__(self):
-        result = next(self._orig_iter)
-        self.count += 1
+        self.count, result = next(self.iter)
         return result
 
-    next = __next__
-
-    def GetCount(self):
-        warnings.warn("Use count attribute directly", DeprecationWarning, stacklevel=2)
-        return self.count
-
-
-# todo, factor out caching capability
-
-
-class iterable_test(dict):
-    def __init__(self, ignore_classes=(str, bytes)):
-        """ignore_classes must include str, because if a string
-        is iterable, so is a single character, and the routine runs
-        into an infinite recursion"""
-        warnings.warn("Slated for removal", DeprecationWarning, stacklevel=2)
-        assert {str} <= set(ignore_classes), 'str must be in ignore_classes'
-        self.ignore_classes = ignore_classes
-
-    def __getitem__(self, candidate):
-        return dict.get(self, type(candidate)) or self._test(candidate)
-
-    def _test(self, candidate):
-        try:
-            if isinstance(candidate, tuple(self.ignore_classes)):
-                raise TypeError
-            iter(candidate)
-            result = True
-        except TypeError:
-            result = False
-        self[type(candidate)] = result
-        return result
-
-
-def iflatten(subject, test=None):
-    if test is None:
-        test = iterable_test()
-    if not test[subject]:
-        yield subject
-    else:
-        for elem in subject:
-            for subelem in iflatten(elem, test):
-                yield subelem
-
-
-def flatten(subject, test=None):
-    """
-    *Deprecated*: Use more_itertools.collapse instead.
-    """
-    warnings.warn(
-        "Use more_itertools.collapse instead", DeprecationWarning, stacklevel=2
-    )
-    return list(more_itertools.collapse(subject, base_type=(bytes,)))
-
 
 def empty():
     """
@@ -501,7 +444,7 @@ def is_empty(iterable):
     return False
 
 
-class Reusable(object):
+class Reusable:
     """
     An iterator that may be reset and reused.
 
@@ -543,8 +486,6 @@ class Reusable(object):
             self.reset()
             raise
 
-    next = __next__
-
 
 def every_other(iterable):
     """
@@ -606,7 +547,7 @@ def peek(iterable):
     return next(peeker), original
 
 
-class Peekable(object):
+class Peekable:
     """
     Wrapper for a traditional iterable to give it a peek attribute.
 
@@ -649,8 +590,6 @@ class Peekable(object):
     def __next__(self):
         return next(self.iterator)
 
-    next = __next__
-
     def peek(self):
         result, self.iterator = peek(self.iterator)
         return result
@@ -772,7 +711,7 @@ def one(item):
     >>> next(numbers)
     2
     """
-    result, = item
+    (result,) = item
     return result
 
 
@@ -816,7 +755,7 @@ def window(iter, pre_size=1, post_size=1):
     return zip(pre_iter, iter, post_iter)
 
 
-class IterSaver(object):
+class IterSaver:
     def __init__(self, n, iterable):
         self.n = n
         self.iterable = iterable
@@ -827,8 +766,6 @@ class IterSaver(object):
             self.buffer.append(next(self.iterable))
         return self.buffer.popleft()
 
-    next = __next__
-
 
 def partition_items(count, bin_size):
     """
@@ -970,7 +907,7 @@ def maybe_single(sequence):
     'a'
     """
     try:
-        single, = sequence
+        (single,) = sequence
     except ValueError:
         return sequence
     return single
@@ -1050,7 +987,9 @@ def assert_ordered(iterable, key=lambda x: x, comp=operator.le):
     )
     for pair in more_itertools.pairwise(iterable):
         keyed = tuple(map(key, pair))
-        assert comp(*keyed), err_tmpl.format(**locals())
+        # cannot use bare assert due to jaraco/jaraco.test#3
+        if not comp(*keyed):
+            raise AssertionError(err_tmpl.format(**locals()))
         yield pair[0]
     yield pair[1]
 
@@ -1214,7 +1153,7 @@ def partition_dict(items, key):
     """
 
     def unmatched(pair):
-        test_key, item, = pair
+        test_key, item = pair
         return test_key != key
 
     items_iter = iter(items.items())
