@@ -6,14 +6,12 @@ in iterables.
 import zlib
 import itertools
 
-import six
-
 from more_itertools.more import peekable
 
 from . import buffer
 
 
-def read_chunks(stream, block_size=2**10):
+def read_chunks(stream, block_size=2 ** 10):
     """
     Given a byte stream with reader, yield chunks of block_size
     until the stream is consusmed.
@@ -25,7 +23,7 @@ def read_chunks(stream, block_size=2**10):
         yield chunk
 
 
-def _load_stream_py3(dc, chunks):
+def load_stream(dc, chunks):
     """
     Given a decompression stream and chunks, yield chunks of
     decompressed data until the compression window ends.
@@ -35,28 +33,13 @@ def _load_stream_py3(dc, chunks):
         yield res
 
 
-def _load_stream_py2(dc, chunks):
-    while True:
-        res = dc.decompress(dc.unconsumed_tail + next(chunks))
-        if not res:
-            break
-        yield res
-
-
-load_stream = [_load_stream_py2, _load_stream_py3][six.PY3]
-load_stream.__doc__ = _load_stream_py3.__doc__
-
-
 def load_streams(chunks):
     """
     Given a gzipped stream of data, yield streams of decompressed data.
     """
     chunks = peekable(chunks)
     while chunks:
-        if six.PY3:
-            dc = zlib.decompressobj(wbits=zlib.MAX_WBITS | 16)
-        else:
-            dc = zlib.decompressobj(zlib.MAX_WBITS | 16)
+        dc = zlib.decompressobj(wbits=zlib.MAX_WBITS | 16)
         yield load_stream(dc, chunks)
         if dc.unused_data:
             chunks = peekable(itertools.chain((dc.unused_data,), chunks))
@@ -70,4 +53,5 @@ def lines_from_stream(chunks):
     for chunk in chunks:
         buf.feed(chunk)
         # when Python 3, yield from buf
-        for _ in buf: yield _
+        for _ in buf:
+            yield _
